==> haskell-checkers-0.5.0-15-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-checkers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: checkers
version: 0.5.0
id: checkers-0.5.0-GmrCmdKnbDLBAiGrYfQvLT
key: checkers-0.5.0-GmrCmdKnbDLBAiGrYfQvLT
license: BSD-3-Clause
copyright: (c) 2008-2013 by Conal Elliott
maintainer: conal@conal.net
author: Conal Elliott
stability: experimental
homepage: https://github.com/conal/checkers
synopsis: Check properties on standard classes and data structures.
description:
    '\'''\''Checkers'\'''\'' wraps up the expected properties associated with various
    standard type classes as QuickCheck properties.  Also some morphism
    properties.  It also provides arbitrary instances and generator combinators
    for common data types.
    .
    &#169; 2008-2013 by Conal Elliott; BSD3 license.
category: Testing
abi: 039088b033cf2c8cc383d83c6c0feb18
exposed: True
exposed-modules:
    Test.QuickCheck.Bottoms Test.QuickCheck.Checkers
    Test.QuickCheck.Classes Test.QuickCheck.Instances
    Test.QuickCheck.Instances.Array Test.QuickCheck.Instances.Char
    Test.QuickCheck.Instances.Eq Test.QuickCheck.Instances.List
    Test.QuickCheck.Instances.Maybe Test.QuickCheck.Instances.Num
    Test.QuickCheck.Instances.Ord Test.QuickCheck.Instances.Tuple
    Test.QuickCheck.Later Test.QuickCheck.Utils
hidden-modules: Control.Monad.Extensions
import-dirs: /usr/lib/ghc-8.6.5/site-local/checkers-0.5.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/checkers-0.5.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/checkers-0.5.0
hs-libraries: HScheckers-0.5.0-GmrCmdKnbDLBAiGrYfQvLT
depends:
    QuickCheck-2.13.2-2FrYL0Zx0JL1157x99MUYA array-0.5.3.0
    base-4.12.0.0 random-1.1-3ypV4EIycgb35PKjTYYr5q
    semigroupoids-5.3.3-JAByPpSn12KzWOYFp8Sfw
haddock-interfaces: /usr/share/doc/haskell-checkers/html/checkers.haddock
haddock-html: /usr/share/doc/haskell-checkers/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-checkers-0.5.0-16-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-checkers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: checkers
version: 0.5.0
id: checkers-0.5.0-I3e2TavM9ABCVZSqXd9jwR
key: checkers-0.5.0-I3e2TavM9ABCVZSqXd9jwR
license: BSD-3-Clause
copyright: (c) 2008-2013 by Conal Elliott
maintainer: conal@conal.net
author: Conal Elliott
stability: experimental
homepage: https://github.com/conal/checkers
synopsis: Check properties on standard classes and data structures.
description:
    '\'''\''Checkers'\'''\'' wraps up the expected properties associated with various
    standard type classes as QuickCheck properties.  Also some morphism
    properties.  It also provides arbitrary instances and generator combinators
    for common data types.
    .
    &#169; 2008-2013 by Conal Elliott; BSD3 license.
category: Testing
abi: 61116323f14db91a351c2323c97512cb
exposed: True
exposed-modules:
    Test.QuickCheck.Bottoms Test.QuickCheck.Checkers
    Test.QuickCheck.Classes Test.QuickCheck.Instances
    Test.QuickCheck.Instances.Array Test.QuickCheck.Instances.Char
    Test.QuickCheck.Instances.Eq Test.QuickCheck.Instances.List
    Test.QuickCheck.Instances.Maybe Test.QuickCheck.Instances.Num
    Test.QuickCheck.Instances.Ord Test.QuickCheck.Instances.Tuple
    Test.QuickCheck.Later Test.QuickCheck.Utils
hidden-modules: Control.Monad.Extensions
import-dirs: /usr/lib/ghc-8.6.5/site-local/checkers-0.5.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/checkers-0.5.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/checkers-0.5.0
hs-libraries: HScheckers-0.5.0-I3e2TavM9ABCVZSqXd9jwR
depends:
    QuickCheck-2.13.2-C3chvSwT3GSBClgQ9bo1MW array-0.5.3.0
    base-4.12.0.0 random-1.1-3ypV4EIycgb35PKjTYYr5q
    semigroupoids-5.3.3-KFEReOTUWayAwY1pytSwUo
haddock-interfaces: /usr/share/doc/haskell-checkers/html/checkers.haddock
haddock-html: /usr/share/doc/haskell-checkers/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
